@@ -11,6 +11,15 @@
     interface for dynamic library loading */
 #undef HAVE_PERL_DYNALOADER
 
+/*  define type bool for Perl 5 headers if missing */
+#undef bool
+
+/*  define DEBUG if we compile with debugging */
+#undef DEBUG_ENABLED
+
+/*  define if libdmalloc.a is available */
+#undef HAVE_DMALLOC
+
 @BOTTOM@
 
 #endif /* CONFIG_AC_H */
