@@ -53,7 +53,7 @@ use Cwd qw(fastcwd);
 @EXPORT = qw();
 
 #   private version number
-$VERSION = "2.2.3";
+$VERSION = "2.2.4";
 
 
 #   autoloading (currently unused)
@@ -130,7 +130,7 @@ sub Translate ($) {
     #   set defaults
     $p->{BeginDelimiter} ||= "<:";
     $p->{EndDelimiter}   ||= ":>";
-    $p->{CaseDelimiters} = 0 if (not defined($p->{CaseDelimiters}));
+    $p->{CaseDelimiters}  = 0 if (not defined($p->{CaseDelimiters}));
     $p->{ConvertEntities} = 0 if (not defined($p->{ConvertEntities}));
 
     #   use XS part: Bristled2Plain
@@ -263,7 +263,7 @@ sub Evaluate ($) {
     #   (on syntax errors) or the generated data 
     #   on STDERR (when generated by the script)
     $error ||= ${$stderr};
-    $error =~ s|\(eval \d+\)|$p->{Name}| if ($p->{Name});
+    $error =~ s|\(eval \d+\)|$p->{Name}| if (defined($error) && $p->{Name});
 
     #   restore Cwd
     chdir($ocwd) if ($p->{Cwd});
